==> vod-cloud-model-1.0.0-sources.jar: com/valor/vod/cloud/model/database/ddo/MfcUserCloudDdo.java <==
package com.valor.vod.cloud.model.database.ddo;


import com.valor.vod.common.database.model.AbstractLMI;

import javax.persistence.*;

//网盘与用户的关联关系
@Entity
@Table(
    name = "mfc_user_cloud",indexes = {
    @Index(name = "i_mfc_user_cloud_account_id",columnList = "account_id"),
//    @Index(name = "i_mfc_user_cloud_account_type", columnList = "account_type"),
    @Index(name = "i_mfc_user_cloud_cid", columnList = "cid")}
)
public class MfcUserCloudDdo extends AbstractLMI {

    @Id
    @Column(
        name = "account_id"
    )
    private Long accountId;

//    @Id
//    @Column(
//        name = "account_type"
//    )
//    private int accountType;

    @Id
    @Column(
        name = "cid"
    )
    private Long cid;


    @Column(
        name = "acct_type"
    )
    private int acctType;

    @Column(
        name = "acct_alias",
        length = 128
    )
    private String acctAlias = "";


    @Column(
        name = "pkg_id"
    )
    private Long pkgId;


    @Column(
        name = "expired_time"
    )
    private Long expiredTime=0L;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

//    public int getAccountType() {
//        return accountType;
//    }
//
//    public void setAccountType(int accountType) {
//        this.accountType = accountType;
//    }

    public Long getCid() {
        return cid;
    }

    public void setCid(Long cid) {
        this.cid = cid;
    }

    public int getAcctType() {
        return acctType;
    }

    public void setAcctType(int acctType) {
        this.acctType = acctType;
    }

    public String getAcctAlias() {
        return acctAlias;
    }

    public void setAcctAlias(String acctAlias) {
        this.acctAlias = acctAlias;
    }

    public Long getPkgId() {
        return pkgId;
    }

    public void setPkgId(Long pkgId) {
        this.pkgId = pkgId;
    }

    public Long getExpiredTime() {
        return expiredTime;
    }

    public void setExpiredTime(Long expiredTime) {
        this.expiredTime = expiredTime;
    }
}

==> vod-cloud-model-3.1.4-sources.jar: com/valor/vod/cloud/model/database/ddo/MfcUserCloudDdo.java <==
package com.valor.vod.cloud.model.database.ddo;


import com.valor.vod.common.database.model.AbstractLMI;

import javax.persistence.*;

//网盘与用户的关联关系
@Entity
@Table(
    name = "mfc_user_cloud",indexes = {
    @Index(name = "i_mfc_user_cloud_account_id",columnList = "account_id"),
//    @Index(name = "i_mfc_user_cloud_account_type", columnList = "account_type"),
    @Index(name = "i_mfc_user_cloud_cid", columnList = "cid")}
)
public class MfcUserCloudDdo extends TenantAbstractLMI {

    @Id
    @Column(
        name = "account_id"
    )
    private Long accountId;

//    @Id
//    @Column(
//        name = "account_type"
//    )
//    private int accountType;

    @Id
    @Column(
        name = "cid"
    )
    private Long cid;


    @Column(
        name = "acct_type"
    )
    private int acctType;

    @Column(
        name = "acct_alias",
        length = 128
    )
    private String acctAlias = "";


    @Column(
        name = "pkg_id"
    )
    private Long pkgId;


    @Column(
        name = "expired_time"
    )
    private Long expiredTime=0L;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

//    public int getAccountType() {
//        return accountType;
//    }
//
//    public void setAccountType(int accountType) {
//        this.accountType = accountType;
//    }

    public Long getCid() {
        return cid;
    }

    public void setCid(Long cid) {
        this.cid = cid;
    }

    public int getAcctType() {
        return acctType;
    }

    public void setAcctType(int acctType) {
        this.acctType = acctType;
    }

    public String getAcctAlias() {
        return acctAlias;
    }

    public void setAcctAlias(String acctAlias) {
        this.acctAlias = acctAlias;
    }

    public Long getPkgId() {
        return pkgId;
    }

    public void setPkgId(Long pkgId) {
        this.pkgId = pkgId;
    }

    public Long getExpiredTime() {
        return expiredTime;
    }

    public void setExpiredTime(Long expiredTime) {
        this.expiredTime = expiredTime;
    }
}
